# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capsule8/api/v0/types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='capsule8/api/v0/types.proto',
  package='capsule8.api.v0',
  syntax='proto3',
  serialized_pb=_b('\n\x1b\x63\x61psule8/api/v0/types.proto\x12\x0f\x63\x61psule8.api.v0\"\x1e\n\x0bIPv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x07\"Q\n\x12IPv4AddressAndPort\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.IPv4Address\x12\x0c\n\x04port\x18\x02 \x01(\r\"(\n\x0bIPv6Address\x12\x0c\n\x04high\x18\x01 \x01(\x06\x12\x0b\n\x03low\x18\x02 \x01(\x06\"Q\n\x12IPv6AddressAndPort\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.IPv6Address\x12\x0c\n\x04port\x18\x02 \x01(\r\"\xe5\x01\n\x0eNetworkAddress\x12\x35\n\x06\x66\x61mily\x18\x01 \x01(\x0e\x32%.capsule8.api.v0.NetworkAddressFamily\x12;\n\x0cipv4_address\x18\n \x01(\x0b\x32#.capsule8.api.v0.IPv4AddressAndPortH\x00\x12;\n\x0cipv6_address\x18\x14 \x01(\x0b\x32#.capsule8.api.v0.IPv6AddressAndPortH\x00\x12\x17\n\rlocal_address\x18\x1e \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ress\"}\n\x0b\x43redentials\x12\x0b\n\x03uid\x18\x01 \x01(\r\x12\x0b\n\x03gid\x18\x02 \x01(\r\x12\x0c\n\x04\x65uid\x18\x03 \x01(\r\x12\x0c\n\x04\x65gid\x18\x04 \x01(\r\x12\x0c\n\x04suid\x18\x05 \x01(\r\x12\x0c\n\x04sgid\x18\x06 \x01(\r\x12\r\n\x05\x66suid\x18\x07 \x01(\r\x12\r\n\x05\x66sgid\x18\x08 \x01(\r*\x9f\x01\n\x14NetworkAddressFamily\x12\"\n\x1eNETWORK_ADDRESS_FAMILY_UNKNOWN\x10\x00\x12\x1f\n\x1bNETWORK_ADDRESS_FAMILY_INET\x10\x01\x12 \n\x1cNETWORK_ADDRESS_FAMILY_INET6\x10\x02\x12 \n\x1cNETWORK_ADDRESS_FAMILY_LOCAL\x10\x03\x62\x06proto3')
)

_NETWORKADDRESSFAMILY = _descriptor.EnumDescriptor(
  name='NetworkAddressFamily',
  full_name='capsule8.api.v0.NetworkAddressFamily',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_INET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_INET6', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_LOCAL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=648,
  serialized_end=807,
)
_sym_db.RegisterEnumDescriptor(_NETWORKADDRESSFAMILY)

NetworkAddressFamily = enum_type_wrapper.EnumTypeWrapper(_NETWORKADDRESSFAMILY)
NETWORK_ADDRESS_FAMILY_UNKNOWN = 0
NETWORK_ADDRESS_FAMILY_INET = 1
NETWORK_ADDRESS_FAMILY_INET6 = 2
NETWORK_ADDRESS_FAMILY_LOCAL = 3



_IPV4ADDRESS = _descriptor.Descriptor(
  name='IPv4Address',
  full_name='capsule8.api.v0.IPv4Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv4Address.address', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=78,
)


_IPV4ADDRESSANDPORT = _descriptor.Descriptor(
  name='IPv4AddressAndPort',
  full_name='capsule8.api.v0.IPv4AddressAndPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv4AddressAndPort.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='capsule8.api.v0.IPv4AddressAndPort.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=161,
)


_IPV6ADDRESS = _descriptor.Descriptor(
  name='IPv6Address',
  full_name='capsule8.api.v0.IPv6Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='high', full_name='capsule8.api.v0.IPv6Address.high', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low', full_name='capsule8.api.v0.IPv6Address.low', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=203,
)


_IPV6ADDRESSANDPORT = _descriptor.Descriptor(
  name='IPv6AddressAndPort',
  full_name='capsule8.api.v0.IPv6AddressAndPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv6AddressAndPort.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='capsule8.api.v0.IPv6AddressAndPort.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=286,
)


_NETWORKADDRESS = _descriptor.Descriptor(
  name='NetworkAddress',
  full_name='capsule8.api.v0.NetworkAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='family', full_name='capsule8.api.v0.NetworkAddress.family', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='capsule8.api.v0.NetworkAddress.ipv4_address', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipv6_address', full_name='capsule8.api.v0.NetworkAddress.ipv6_address', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_address', full_name='capsule8.api.v0.NetworkAddress.local_address', index=3,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='capsule8.api.v0.NetworkAddress.address',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=289,
  serialized_end=518,
)


_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='capsule8.api.v0.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='capsule8.api.v0.Credentials.uid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='capsule8.api.v0.Credentials.gid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='euid', full_name='capsule8.api.v0.Credentials.euid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egid', full_name='capsule8.api.v0.Credentials.egid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suid', full_name='capsule8.api.v0.Credentials.suid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sgid', full_name='capsule8.api.v0.Credentials.sgid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsuid', full_name='capsule8.api.v0.Credentials.fsuid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsgid', full_name='capsule8.api.v0.Credentials.fsgid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=645,
)

_IPV4ADDRESSANDPORT.fields_by_name['address'].message_type = _IPV4ADDRESS
_IPV6ADDRESSANDPORT.fields_by_name['address'].message_type = _IPV6ADDRESS
_NETWORKADDRESS.fields_by_name['family'].enum_type = _NETWORKADDRESSFAMILY
_NETWORKADDRESS.fields_by_name['ipv4_address'].message_type = _IPV4ADDRESSANDPORT
_NETWORKADDRESS.fields_by_name['ipv6_address'].message_type = _IPV6ADDRESSANDPORT
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['ipv4_address'])
_NETWORKADDRESS.fields_by_name['ipv4_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['ipv6_address'])
_NETWORKADDRESS.fields_by_name['ipv6_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['local_address'])
_NETWORKADDRESS.fields_by_name['local_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
DESCRIPTOR.message_types_by_name['IPv4Address'] = _IPV4ADDRESS
DESCRIPTOR.message_types_by_name['IPv4AddressAndPort'] = _IPV4ADDRESSANDPORT
DESCRIPTOR.message_types_by_name['IPv6Address'] = _IPV6ADDRESS
DESCRIPTOR.message_types_by_name['IPv6AddressAndPort'] = _IPV6ADDRESSANDPORT
DESCRIPTOR.message_types_by_name['NetworkAddress'] = _NETWORKADDRESS
DESCRIPTOR.message_types_by_name['Credentials'] = _CREDENTIALS
DESCRIPTOR.enum_types_by_name['NetworkAddressFamily'] = _NETWORKADDRESSFAMILY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IPv4Address = _reflection.GeneratedProtocolMessageType('IPv4Address', (_message.Message,), dict(
  DESCRIPTOR = _IPV4ADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv4Address)
  ))
_sym_db.RegisterMessage(IPv4Address)

IPv4AddressAndPort = _reflection.GeneratedProtocolMessageType('IPv4AddressAndPort', (_message.Message,), dict(
  DESCRIPTOR = _IPV4ADDRESSANDPORT,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv4AddressAndPort)
  ))
_sym_db.RegisterMessage(IPv4AddressAndPort)

IPv6Address = _reflection.GeneratedProtocolMessageType('IPv6Address', (_message.Message,), dict(
  DESCRIPTOR = _IPV6ADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv6Address)
  ))
_sym_db.RegisterMessage(IPv6Address)

IPv6AddressAndPort = _reflection.GeneratedProtocolMessageType('IPv6AddressAndPort', (_message.Message,), dict(
  DESCRIPTOR = _IPV6ADDRESSANDPORT,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv6AddressAndPort)
  ))
_sym_db.RegisterMessage(IPv6AddressAndPort)

NetworkAddress = _reflection.GeneratedProtocolMessageType('NetworkAddress', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.NetworkAddress)
  ))
_sym_db.RegisterMessage(NetworkAddress)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.Credentials)
  ))
_sym_db.RegisterMessage(Credentials)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capsule8/api/v0/telemetry_event.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capsule8.api.v0 import types_pb2 as capsule8_dot_api_dot_v0_dot_types__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='capsule8/api/v0/telemetry_event.proto',
  package='capsule8.api.v0',
  syntax='proto3',
  serialized_pb=_b('\n%capsule8/api/v0/telemetry_event.proto\x12\x0f\x63\x61psule8.api.v0\x1a\x1b\x63\x61psule8/api/v0/types.proto\"\xea\x06\n\x0eTelemetryEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nprocess_id\x18\x02 \x01(\t\x12\x13\n\x0bprocess_pid\x18\x03 \x01(\x05\x12\x14\n\x0c\x63ontainer_id\x18\x04 \x01(\t\x12\x11\n\tsensor_id\x18\x05 \x01(\t\x12\x1e\n\x16sensor_sequence_number\x18\x06 \x01(\x04\x12\x1d\n\x15sensor_monotime_nanos\x18\x07 \x01(\x03\x12\x31\n\x0fprocess_lineage\x18\x08 \x03(\x0b\x32\x18.capsule8.api.v0.Process\x12\x16\n\x0e\x63ontainer_name\x18\x1e \x01(\t\x12\x10\n\x08image_id\x18\x1f \x01(\t\x12\x12\n\nimage_name\x18  \x01(\t\x12\x30\n\x07syscall\x18\n \x01(\x0b\x32\x1d.capsule8.api.v0.SyscallEventH\x00\x12\x30\n\x07process\x18\x0b \x01(\x0b\x32\x1d.capsule8.api.v0.ProcessEventH\x00\x12*\n\x04\x66ile\x18\x0c \x01(\x0b\x32\x1a.capsule8.api.v0.FileEventH\x00\x12?\n\x0bkernel_call\x18\r \x01(\x0b\x32(.capsule8.api.v0.KernelFunctionCallEventH\x00\x12\x30\n\x07network\x18\x0e \x01(\x0b\x32\x1d.capsule8.api.v0.NetworkEventH\x00\x12\x38\n\x0bperformance\x18\x0f \x01(\x0b\x32!.capsule8.api.v0.PerformanceEventH\x00\x12\x34\n\tcontainer\x18\x14 \x01(\x0b\x32\x1f.capsule8.api.v0.ContainerEventH\x00\x12\x30\n\x07\x63hargen\x18\x64 \x01(\x0b\x32\x1d.capsule8.api.v0.ChargenEventH\x00\x12.\n\x06ticker\x18\x65 \x01(\x0b\x32\x1c.capsule8.api.v0.TickerEventH\x00\x12\x0c\n\x03\x63pu\x18\xc9\x01 \x01(\x05\x12\x32\n\x0b\x63redentials\x18\xca\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.Credentials\x12\x15\n\x0cprocess_tgid\x18\xcb\x01 \x01(\x05\x42\x07\n\x05\x65ventJ\x06\x08\xc8\x01\x10\xc9\x01R\x0bprocess_tid\"1\n\x0c\x43hargenEvent\x12\r\n\x05index\x18\x01 \x01(\x04\x12\x12\n\ncharacters\x18\x02 \x01(\t\"3\n\x0bTickerEvent\x12\x0f\n\x07seconds\x18\x01 \x01(\x03\x12\x13\n\x0bnanoseconds\x18\x02 \x01(\x03\"\x95\x02\n\x0e\x43ontainerEvent\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.capsule8.api.v0.ContainerEventType\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08image_id\x18\n \x01(\t\x12\x12\n\nimage_name\x18\x0b \x01(\t\x12\x10\n\x08host_pid\x18\x14 \x01(\x11\x12\x11\n\texit_code\x18\x1e \x01(\x11\x12\x13\n\x0b\x65xit_status\x18\x1f \x01(\r\x12\x13\n\x0b\x65xit_signal\x18  \x01(\r\x12\x18\n\x10\x65xit_core_dumped\x18! \x01(\x08\x12\x1a\n\x12\x64ocker_config_json\x18\x64 \x01(\t\x12\x17\n\x0foci_config_json\x18\x65 \x01(\t\"\x8b\x02\n\x0cProcessEvent\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.ProcessEventType\x12\x16\n\x0e\x66ork_child_pid\x18\n \x01(\x11\x12\x15\n\rfork_child_id\x18\x0b \x01(\t\x12\x15\n\rexec_filename\x18\x14 \x01(\t\x12\x19\n\x11\x65xec_command_line\x18\x15 \x03(\t\x12\x11\n\texit_code\x18\x1e \x01(\x11\x12\x13\n\x0b\x65xit_status\x18\x1f \x01(\r\x12\x13\n\x0b\x65xit_signal\x18  \x01(\r\x12\x18\n\x10\x65xit_core_dumped\x18! \x01(\x08\x12\x12\n\nupdate_cwd\x18( \x01(\t\"\xac\x01\n\x0cSyscallEvent\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.SyscallEventType\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x0c\n\x04\x61rg0\x18\n \x01(\x04\x12\x0c\n\x04\x61rg1\x18\x0b \x01(\x04\x12\x0c\n\x04\x61rg2\x18\x0c \x01(\x04\x12\x0c\n\x04\x61rg3\x18\r \x01(\x04\x12\x0c\n\x04\x61rg4\x18\x0e \x01(\x04\x12\x0c\n\x04\x61rg5\x18\x0f \x01(\x04\x12\x0b\n\x03ret\x18\x14 \x01(\x03\"r\n\tFileEvent\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.capsule8.api.v0.FileEventType\x12\x10\n\x08\x66ilename\x18\n \x01(\t\x12\x12\n\nopen_flags\x18\x0b \x01(\x11\x12\x11\n\topen_mode\x18\x0c \x01(\x11\"\'\n\x07Process\x12\x0b\n\x03pid\x18\x01 \x01(\x11\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"\x9d\x04\n\x17KernelFunctionCallEvent\x12J\n\targuments\x18\x01 \x03(\x0b\x32\x37.capsule8.api.v0.KernelFunctionCallEvent.ArgumentsEntry\x1a\xbe\x01\n\nFieldValue\x12\x46\n\nfield_type\x18\x01 \x01(\x0e\x32\x32.capsule8.api.v0.KernelFunctionCallEvent.FieldType\x12\x15\n\x0b\x62ytes_value\x18\x02 \x01(\x0cH\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x16\n\x0csigned_value\x18\x04 \x01(\x12H\x00\x12\x18\n\x0eunsigned_value\x18\x05 \x01(\x04H\x00\x42\x07\n\x05value\x1a\x65\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x33.capsule8.api.v0.KernelFunctionCallEvent.FieldValue:\x02\x38\x01\"\x8d\x01\n\tFieldType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05\x42YTES\x10\x01\x12\n\n\x06STRING\x10\x02\x12\t\n\x05SINT8\x10\x03\x12\n\n\x06SINT16\x10\x04\x12\n\n\x06SINT32\x10\x05\x12\n\n\x06SINT64\x10\x06\x12\t\n\x05UINT8\x10\x07\x12\n\n\x06UINT16\x10\x08\x12\n\n\x06UINT32\x10\t\x12\n\n\x06UINT64\x10\n\"\xa2\x01\n\x0cNetworkEvent\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.NetworkEventType\x12\x0e\n\x06sockfd\x18\n \x01(\x04\x12\x30\n\x07\x61\x64\x64ress\x18\x0b \x01(\x0b\x32\x1f.capsule8.api.v0.NetworkAddress\x12\x0e\n\x06result\x18\x0c \x01(\x12\x12\x0f\n\x07\x62\x61\x63klog\x18\r \x01(\x04\"k\n\x15PerformanceEventValue\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.capsule8.api.v0.PerformanceEventType\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x04\x12\r\n\x05value\x18\x03 \x01(\x04\"\x82\x01\n\x10PerformanceEvent\x12\x1a\n\x12total_time_enabled\x18\x01 \x01(\x04\x12\x1a\n\x12total_time_running\x18\x02 \x01(\x04\x12\x36\n\x06values\x18\x03 \x03(\x0b\x32&.capsule8.api.v0.PerformanceEventValue*\xe1\x01\n\x12\x43ontainerEventType\x12 \n\x1c\x43ONTAINER_EVENT_TYPE_UNKNOWN\x10\x00\x12 \n\x1c\x43ONTAINER_EVENT_TYPE_CREATED\x10\x01\x12 \n\x1c\x43ONTAINER_EVENT_TYPE_RUNNING\x10\x02\x12\x1f\n\x1b\x43ONTAINER_EVENT_TYPE_EXITED\x10\x03\x12\"\n\x1e\x43ONTAINER_EVENT_TYPE_DESTROYED\x10\x04\x12 \n\x1c\x43ONTAINER_EVENT_TYPE_UPDATED\x10\x05*\xa8\x01\n\x10ProcessEventType\x12\x1e\n\x1aPROCESS_EVENT_TYPE_UNKNOWN\x10\x00\x12\x1b\n\x17PROCESS_EVENT_TYPE_FORK\x10\x01\x12\x1b\n\x17PROCESS_EVENT_TYPE_EXEC\x10\x02\x12\x1b\n\x17PROCESS_EVENT_TYPE_EXIT\x10\x03\x12\x1d\n\x19PROCESS_EVENT_TYPE_UPDATE\x10\x04*m\n\x10SyscallEventType\x12\x1e\n\x1aSYSCALL_EVENT_TYPE_UNKNOWN\x10\x00\x12\x1c\n\x18SYSCALL_EVENT_TYPE_ENTER\x10\x01\x12\x1b\n\x17SYSCALL_EVENT_TYPE_EXIT\x10\x02*F\n\rFileEventType\x12\x1b\n\x17\x46ILE_EVENT_TYPE_UNKNOWN\x10\x00\x12\x18\n\x14\x46ILE_EVENT_TYPE_OPEN\x10\x01*\x9f\x01\n\x1bKernelFunctionCallEventType\x12+\n\'KERNEL_FUNCTION_CALL_EVENT_TYPE_UNKNOWN\x10\x00\x12)\n%KERNEL_FUNCTION_CALL_EVENT_TYPE_ENTER\x10\x01\x12(\n$KERNEL_FUNCTION_CALL_EVENT_TYPE_EXIT\x10\x02*\x82\x04\n\x10NetworkEventType\x12\x1e\n\x1aNETWORK_EVENT_TYPE_UNKNOWN\x10\x00\x12&\n\"NETWORK_EVENT_TYPE_CONNECT_ATTEMPT\x10\x01\x12%\n!NETWORK_EVENT_TYPE_CONNECT_RESULT\x10\x02\x12#\n\x1fNETWORK_EVENT_TYPE_BIND_ATTEMPT\x10\x03\x12\"\n\x1eNETWORK_EVENT_TYPE_BIND_RESULT\x10\x04\x12%\n!NETWORK_EVENT_TYPE_LISTEN_ATTEMPT\x10\x05\x12$\n NETWORK_EVENT_TYPE_LISTEN_RESULT\x10\x06\x12%\n!NETWORK_EVENT_TYPE_ACCEPT_ATTEMPT\x10\x07\x12$\n NETWORK_EVENT_TYPE_ACCEPT_RESULT\x10\x08\x12%\n!NETWORK_EVENT_TYPE_SENDTO_ATTEMPT\x10\t\x12$\n NETWORK_EVENT_TYPE_SENDTO_RESULT\x10\n\x12\'\n#NETWORK_EVENT_TYPE_RECVFROM_ATTEMPT\x10\x0b\x12&\n\"NETWORK_EVENT_TYPE_RECVFROM_RESULT\x10\x0c*\xaf\x01\n\x14PerformanceEventType\x12\"\n\x1ePERFORMANCE_EVENT_TYPE_UNKNOWN\x10\x00\x12#\n\x1fPERFORMANCE_EVENT_TYPE_HARDWARE\x10\x01\x12)\n%PERFORMANCE_EVENT_TYPE_HARDWARE_CACHE\x10\x02\x12#\n\x1fPERFORMANCE_EVENT_TYPE_SOFTWARE\x10\x03\x62\x06proto3')
  ,
  dependencies=[capsule8_dot_api_dot_v0_dot_types__pb2.DESCRIPTOR,])

_CONTAINEREVENTTYPE = _descriptor.EnumDescriptor(
  name='ContainerEventType',
  full_name='capsule8.api.v0.ContainerEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_CREATED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_RUNNING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_EXITED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_DESTROYED', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER_EVENT_TYPE_UPDATED', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2902,
  serialized_end=3127,
)
_sym_db.RegisterEnumDescriptor(_CONTAINEREVENTTYPE)

ContainerEventType = enum_type_wrapper.EnumTypeWrapper(_CONTAINEREVENTTYPE)
_PROCESSEVENTTYPE = _descriptor.EnumDescriptor(
  name='ProcessEventType',
  full_name='capsule8.api.v0.ProcessEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROCESS_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_EVENT_TYPE_FORK', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_EVENT_TYPE_EXEC', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_EVENT_TYPE_EXIT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_EVENT_TYPE_UPDATE', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3130,
  serialized_end=3298,
)
_sym_db.RegisterEnumDescriptor(_PROCESSEVENTTYPE)

ProcessEventType = enum_type_wrapper.EnumTypeWrapper(_PROCESSEVENTTYPE)
_SYSCALLEVENTTYPE = _descriptor.EnumDescriptor(
  name='SyscallEventType',
  full_name='capsule8.api.v0.SyscallEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYSCALL_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSCALL_EVENT_TYPE_ENTER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSCALL_EVENT_TYPE_EXIT', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3300,
  serialized_end=3409,
)
_sym_db.RegisterEnumDescriptor(_SYSCALLEVENTTYPE)

SyscallEventType = enum_type_wrapper.EnumTypeWrapper(_SYSCALLEVENTTYPE)
_FILEEVENTTYPE = _descriptor.EnumDescriptor(
  name='FileEventType',
  full_name='capsule8.api.v0.FileEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FILE_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FILE_EVENT_TYPE_OPEN', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3411,
  serialized_end=3481,
)
_sym_db.RegisterEnumDescriptor(_FILEEVENTTYPE)

FileEventType = enum_type_wrapper.EnumTypeWrapper(_FILEEVENTTYPE)
_KERNELFUNCTIONCALLEVENTTYPE = _descriptor.EnumDescriptor(
  name='KernelFunctionCallEventType',
  full_name='capsule8.api.v0.KernelFunctionCallEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='KERNEL_FUNCTION_CALL_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KERNEL_FUNCTION_CALL_EVENT_TYPE_ENTER', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KERNEL_FUNCTION_CALL_EVENT_TYPE_EXIT', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3484,
  serialized_end=3643,
)
_sym_db.RegisterEnumDescriptor(_KERNELFUNCTIONCALLEVENTTYPE)

KernelFunctionCallEventType = enum_type_wrapper.EnumTypeWrapper(_KERNELFUNCTIONCALLEVENTTYPE)
_NETWORKEVENTTYPE = _descriptor.EnumDescriptor(
  name='NetworkEventType',
  full_name='capsule8.api.v0.NetworkEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_CONNECT_ATTEMPT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_CONNECT_RESULT', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_BIND_ATTEMPT', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_BIND_RESULT', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_LISTEN_ATTEMPT', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_LISTEN_RESULT', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_ACCEPT_ATTEMPT', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_ACCEPT_RESULT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_SENDTO_ATTEMPT', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_SENDTO_RESULT', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_RECVFROM_ATTEMPT', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_EVENT_TYPE_RECVFROM_RESULT', index=12, number=12,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3646,
  serialized_end=4160,
)
_sym_db.RegisterEnumDescriptor(_NETWORKEVENTTYPE)

NetworkEventType = enum_type_wrapper.EnumTypeWrapper(_NETWORKEVENTTYPE)
_PERFORMANCEEVENTTYPE = _descriptor.EnumDescriptor(
  name='PerformanceEventType',
  full_name='capsule8.api.v0.PerformanceEventType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERFORMANCE_EVENT_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERFORMANCE_EVENT_TYPE_HARDWARE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERFORMANCE_EVENT_TYPE_HARDWARE_CACHE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERFORMANCE_EVENT_TYPE_SOFTWARE', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4163,
  serialized_end=4338,
)
_sym_db.RegisterEnumDescriptor(_PERFORMANCEEVENTTYPE)

PerformanceEventType = enum_type_wrapper.EnumTypeWrapper(_PERFORMANCEEVENTTYPE)
CONTAINER_EVENT_TYPE_UNKNOWN = 0
CONTAINER_EVENT_TYPE_CREATED = 1
CONTAINER_EVENT_TYPE_RUNNING = 2
CONTAINER_EVENT_TYPE_EXITED = 3
CONTAINER_EVENT_TYPE_DESTROYED = 4
CONTAINER_EVENT_TYPE_UPDATED = 5
PROCESS_EVENT_TYPE_UNKNOWN = 0
PROCESS_EVENT_TYPE_FORK = 1
PROCESS_EVENT_TYPE_EXEC = 2
PROCESS_EVENT_TYPE_EXIT = 3
PROCESS_EVENT_TYPE_UPDATE = 4
SYSCALL_EVENT_TYPE_UNKNOWN = 0
SYSCALL_EVENT_TYPE_ENTER = 1
SYSCALL_EVENT_TYPE_EXIT = 2
FILE_EVENT_TYPE_UNKNOWN = 0
FILE_EVENT_TYPE_OPEN = 1
KERNEL_FUNCTION_CALL_EVENT_TYPE_UNKNOWN = 0
KERNEL_FUNCTION_CALL_EVENT_TYPE_ENTER = 1
KERNEL_FUNCTION_CALL_EVENT_TYPE_EXIT = 2
NETWORK_EVENT_TYPE_UNKNOWN = 0
NETWORK_EVENT_TYPE_CONNECT_ATTEMPT = 1
NETWORK_EVENT_TYPE_CONNECT_RESULT = 2
NETWORK_EVENT_TYPE_BIND_ATTEMPT = 3
NETWORK_EVENT_TYPE_BIND_RESULT = 4
NETWORK_EVENT_TYPE_LISTEN_ATTEMPT = 5
NETWORK_EVENT_TYPE_LISTEN_RESULT = 6
NETWORK_EVENT_TYPE_ACCEPT_ATTEMPT = 7
NETWORK_EVENT_TYPE_ACCEPT_RESULT = 8
NETWORK_EVENT_TYPE_SENDTO_ATTEMPT = 9
NETWORK_EVENT_TYPE_SENDTO_RESULT = 10
NETWORK_EVENT_TYPE_RECVFROM_ATTEMPT = 11
NETWORK_EVENT_TYPE_RECVFROM_RESULT = 12
PERFORMANCE_EVENT_TYPE_UNKNOWN = 0
PERFORMANCE_EVENT_TYPE_HARDWARE = 1
PERFORMANCE_EVENT_TYPE_HARDWARE_CACHE = 2
PERFORMANCE_EVENT_TYPE_SOFTWARE = 3


_KERNELFUNCTIONCALLEVENT_FIELDTYPE = _descriptor.EnumDescriptor(
  name='FieldType',
  full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BYTES', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT8', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT16', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT32', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT64', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT8', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT16', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT32', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=10, number=10,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2351,
  serialized_end=2492,
)
_sym_db.RegisterEnumDescriptor(_KERNELFUNCTIONCALLEVENT_FIELDTYPE)


_TELEMETRYEVENT = _descriptor.Descriptor(
  name='TelemetryEvent',
  full_name='capsule8.api.v0.TelemetryEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='capsule8.api.v0.TelemetryEvent.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='capsule8.api.v0.TelemetryEvent.process_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_pid', full_name='capsule8.api.v0.TelemetryEvent.process_pid', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_id', full_name='capsule8.api.v0.TelemetryEvent.container_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensor_id', full_name='capsule8.api.v0.TelemetryEvent.sensor_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensor_sequence_number', full_name='capsule8.api.v0.TelemetryEvent.sensor_sequence_number', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensor_monotime_nanos', full_name='capsule8.api.v0.TelemetryEvent.sensor_monotime_nanos', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_lineage', full_name='capsule8.api.v0.TelemetryEvent.process_lineage', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_name', full_name='capsule8.api.v0.TelemetryEvent.container_name', index=8,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='capsule8.api.v0.TelemetryEvent.image_id', index=9,
      number=31, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_name', full_name='capsule8.api.v0.TelemetryEvent.image_name', index=10,
      number=32, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='syscall', full_name='capsule8.api.v0.TelemetryEvent.syscall', index=11,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process', full_name='capsule8.api.v0.TelemetryEvent.process', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file', full_name='capsule8.api.v0.TelemetryEvent.file', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kernel_call', full_name='capsule8.api.v0.TelemetryEvent.kernel_call', index=14,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network', full_name='capsule8.api.v0.TelemetryEvent.network', index=15,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance', full_name='capsule8.api.v0.TelemetryEvent.performance', index=16,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container', full_name='capsule8.api.v0.TelemetryEvent.container', index=17,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chargen', full_name='capsule8.api.v0.TelemetryEvent.chargen', index=18,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='capsule8.api.v0.TelemetryEvent.ticker', index=19,
      number=101, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu', full_name='capsule8.api.v0.TelemetryEvent.cpu', index=20,
      number=201, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='credentials', full_name='capsule8.api.v0.TelemetryEvent.credentials', index=21,
      number=202, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_tgid', full_name='capsule8.api.v0.TelemetryEvent.process_tgid', index=22,
      number=203, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='event', full_name='capsule8.api.v0.TelemetryEvent.event',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=88,
  serialized_end=962,
)


_CHARGENEVENT = _descriptor.Descriptor(
  name='ChargenEvent',
  full_name='capsule8.api.v0.ChargenEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='capsule8.api.v0.ChargenEvent.index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='characters', full_name='capsule8.api.v0.ChargenEvent.characters', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=964,
  serialized_end=1013,
)


_TICKEREVENT = _descriptor.Descriptor(
  name='TickerEvent',
  full_name='capsule8.api.v0.TickerEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='seconds', full_name='capsule8.api.v0.TickerEvent.seconds', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nanoseconds', full_name='capsule8.api.v0.TickerEvent.nanoseconds', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1015,
  serialized_end=1066,
)


_CONTAINEREVENT = _descriptor.Descriptor(
  name='ContainerEvent',
  full_name='capsule8.api.v0.ContainerEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.ContainerEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='capsule8.api.v0.ContainerEvent.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='capsule8.api.v0.ContainerEvent.image_id', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_name', full_name='capsule8.api.v0.ContainerEvent.image_name', index=3,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host_pid', full_name='capsule8.api.v0.ContainerEvent.host_pid', index=4,
      number=20, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='capsule8.api.v0.ContainerEvent.exit_code', index=5,
      number=30, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_status', full_name='capsule8.api.v0.ContainerEvent.exit_status', index=6,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_signal', full_name='capsule8.api.v0.ContainerEvent.exit_signal', index=7,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_core_dumped', full_name='capsule8.api.v0.ContainerEvent.exit_core_dumped', index=8,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='docker_config_json', full_name='capsule8.api.v0.ContainerEvent.docker_config_json', index=9,
      number=100, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='oci_config_json', full_name='capsule8.api.v0.ContainerEvent.oci_config_json', index=10,
      number=101, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1069,
  serialized_end=1346,
)


_PROCESSEVENT = _descriptor.Descriptor(
  name='ProcessEvent',
  full_name='capsule8.api.v0.ProcessEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.ProcessEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fork_child_pid', full_name='capsule8.api.v0.ProcessEvent.fork_child_pid', index=1,
      number=10, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fork_child_id', full_name='capsule8.api.v0.ProcessEvent.fork_child_id', index=2,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_filename', full_name='capsule8.api.v0.ProcessEvent.exec_filename', index=3,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_command_line', full_name='capsule8.api.v0.ProcessEvent.exec_command_line', index=4,
      number=21, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='capsule8.api.v0.ProcessEvent.exit_code', index=5,
      number=30, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_status', full_name='capsule8.api.v0.ProcessEvent.exit_status', index=6,
      number=31, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_signal', full_name='capsule8.api.v0.ProcessEvent.exit_signal', index=7,
      number=32, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_core_dumped', full_name='capsule8.api.v0.ProcessEvent.exit_core_dumped', index=8,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='update_cwd', full_name='capsule8.api.v0.ProcessEvent.update_cwd', index=9,
      number=40, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1349,
  serialized_end=1616,
)


_SYSCALLEVENT = _descriptor.Descriptor(
  name='SyscallEvent',
  full_name='capsule8.api.v0.SyscallEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.SyscallEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='capsule8.api.v0.SyscallEvent.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg0', full_name='capsule8.api.v0.SyscallEvent.arg0', index=2,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg1', full_name='capsule8.api.v0.SyscallEvent.arg1', index=3,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg2', full_name='capsule8.api.v0.SyscallEvent.arg2', index=4,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg3', full_name='capsule8.api.v0.SyscallEvent.arg3', index=5,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg4', full_name='capsule8.api.v0.SyscallEvent.arg4', index=6,
      number=14, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg5', full_name='capsule8.api.v0.SyscallEvent.arg5', index=7,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ret', full_name='capsule8.api.v0.SyscallEvent.ret', index=8,
      number=20, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1791,
)


_FILEEVENT = _descriptor.Descriptor(
  name='FileEvent',
  full_name='capsule8.api.v0.FileEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.FileEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='capsule8.api.v0.FileEvent.filename', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_flags', full_name='capsule8.api.v0.FileEvent.open_flags', index=2,
      number=11, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_mode', full_name='capsule8.api.v0.FileEvent.open_mode', index=3,
      number=12, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1793,
  serialized_end=1907,
)


_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='capsule8.api.v0.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='capsule8.api.v0.Process.pid', index=0,
      number=1, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='capsule8.api.v0.Process.command', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1909,
  serialized_end=1948,
)


_KERNELFUNCTIONCALLEVENT_FIELDVALUE = _descriptor.Descriptor(
  name='FieldValue',
  full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_type', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.field_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bytes_value', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.bytes_value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.string_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signed_value', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.signed_value', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unsigned_value', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.unsigned_value', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='capsule8.api.v0.KernelFunctionCallEvent.FieldValue.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2055,
  serialized_end=2245,
)

_KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY = _descriptor.Descriptor(
  name='ArgumentsEntry',
  full_name='capsule8.api.v0.KernelFunctionCallEvent.ArgumentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='capsule8.api.v0.KernelFunctionCallEvent.ArgumentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='capsule8.api.v0.KernelFunctionCallEvent.ArgumentsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2247,
  serialized_end=2348,
)

_KERNELFUNCTIONCALLEVENT = _descriptor.Descriptor(
  name='KernelFunctionCallEvent',
  full_name='capsule8.api.v0.KernelFunctionCallEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='arguments', full_name='capsule8.api.v0.KernelFunctionCallEvent.arguments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KERNELFUNCTIONCALLEVENT_FIELDVALUE, _KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY, ],
  enum_types=[
    _KERNELFUNCTIONCALLEVENT_FIELDTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2492,
)


_NETWORKEVENT = _descriptor.Descriptor(
  name='NetworkEvent',
  full_name='capsule8.api.v0.NetworkEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.NetworkEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sockfd', full_name='capsule8.api.v0.NetworkEvent.sockfd', index=1,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.NetworkEvent.address', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='capsule8.api.v0.NetworkEvent.result', index=3,
      number=12, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='backlog', full_name='capsule8.api.v0.NetworkEvent.backlog', index=4,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2495,
  serialized_end=2657,
)


_PERFORMANCEEVENTVALUE = _descriptor.Descriptor(
  name='PerformanceEventValue',
  full_name='capsule8.api.v0.PerformanceEventValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.PerformanceEventValue.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='capsule8.api.v0.PerformanceEventValue.config', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='capsule8.api.v0.PerformanceEventValue.value', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2659,
  serialized_end=2766,
)


_PERFORMANCEEVENT = _descriptor.Descriptor(
  name='PerformanceEvent',
  full_name='capsule8.api.v0.PerformanceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time_enabled', full_name='capsule8.api.v0.PerformanceEvent.total_time_enabled', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_time_running', full_name='capsule8.api.v0.PerformanceEvent.total_time_running', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='capsule8.api.v0.PerformanceEvent.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2769,
  serialized_end=2899,
)

_TELEMETRYEVENT.fields_by_name['process_lineage'].message_type = _PROCESS
_TELEMETRYEVENT.fields_by_name['syscall'].message_type = _SYSCALLEVENT
_TELEMETRYEVENT.fields_by_name['process'].message_type = _PROCESSEVENT
_TELEMETRYEVENT.fields_by_name['file'].message_type = _FILEEVENT
_TELEMETRYEVENT.fields_by_name['kernel_call'].message_type = _KERNELFUNCTIONCALLEVENT
_TELEMETRYEVENT.fields_by_name['network'].message_type = _NETWORKEVENT
_TELEMETRYEVENT.fields_by_name['performance'].message_type = _PERFORMANCEEVENT
_TELEMETRYEVENT.fields_by_name['container'].message_type = _CONTAINEREVENT
_TELEMETRYEVENT.fields_by_name['chargen'].message_type = _CHARGENEVENT
_TELEMETRYEVENT.fields_by_name['ticker'].message_type = _TICKEREVENT
_TELEMETRYEVENT.fields_by_name['credentials'].message_type = capsule8_dot_api_dot_v0_dot_types__pb2._CREDENTIALS
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['syscall'])
_TELEMETRYEVENT.fields_by_name['syscall'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['process'])
_TELEMETRYEVENT.fields_by_name['process'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['file'])
_TELEMETRYEVENT.fields_by_name['file'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['kernel_call'])
_TELEMETRYEVENT.fields_by_name['kernel_call'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['network'])
_TELEMETRYEVENT.fields_by_name['network'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['performance'])
_TELEMETRYEVENT.fields_by_name['performance'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['container'])
_TELEMETRYEVENT.fields_by_name['container'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['chargen'])
_TELEMETRYEVENT.fields_by_name['chargen'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_TELEMETRYEVENT.oneofs_by_name['event'].fields.append(
  _TELEMETRYEVENT.fields_by_name['ticker'])
_TELEMETRYEVENT.fields_by_name['ticker'].containing_oneof = _TELEMETRYEVENT.oneofs_by_name['event']
_CONTAINEREVENT.fields_by_name['type'].enum_type = _CONTAINEREVENTTYPE
_PROCESSEVENT.fields_by_name['type'].enum_type = _PROCESSEVENTTYPE
_SYSCALLEVENT.fields_by_name['type'].enum_type = _SYSCALLEVENTTYPE
_FILEEVENT.fields_by_name['type'].enum_type = _FILEEVENTTYPE
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['field_type'].enum_type = _KERNELFUNCTIONCALLEVENT_FIELDTYPE
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.containing_type = _KERNELFUNCTIONCALLEVENT
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value'].fields.append(
  _KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['bytes_value'])
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['bytes_value'].containing_oneof = _KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value']
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value'].fields.append(
  _KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['string_value'])
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['string_value'].containing_oneof = _KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value']
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value'].fields.append(
  _KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['signed_value'])
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['signed_value'].containing_oneof = _KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value']
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value'].fields.append(
  _KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['unsigned_value'])
_KERNELFUNCTIONCALLEVENT_FIELDVALUE.fields_by_name['unsigned_value'].containing_oneof = _KERNELFUNCTIONCALLEVENT_FIELDVALUE.oneofs_by_name['value']
_KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY.fields_by_name['value'].message_type = _KERNELFUNCTIONCALLEVENT_FIELDVALUE
_KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY.containing_type = _KERNELFUNCTIONCALLEVENT
_KERNELFUNCTIONCALLEVENT.fields_by_name['arguments'].message_type = _KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY
_KERNELFUNCTIONCALLEVENT_FIELDTYPE.containing_type = _KERNELFUNCTIONCALLEVENT
_NETWORKEVENT.fields_by_name['type'].enum_type = _NETWORKEVENTTYPE
_NETWORKEVENT.fields_by_name['address'].message_type = capsule8_dot_api_dot_v0_dot_types__pb2._NETWORKADDRESS
_PERFORMANCEEVENTVALUE.fields_by_name['type'].enum_type = _PERFORMANCEEVENTTYPE
_PERFORMANCEEVENT.fields_by_name['values'].message_type = _PERFORMANCEEVENTVALUE
DESCRIPTOR.message_types_by_name['TelemetryEvent'] = _TELEMETRYEVENT
DESCRIPTOR.message_types_by_name['ChargenEvent'] = _CHARGENEVENT
DESCRIPTOR.message_types_by_name['TickerEvent'] = _TICKEREVENT
DESCRIPTOR.message_types_by_name['ContainerEvent'] = _CONTAINEREVENT
DESCRIPTOR.message_types_by_name['ProcessEvent'] = _PROCESSEVENT
DESCRIPTOR.message_types_by_name['SyscallEvent'] = _SYSCALLEVENT
DESCRIPTOR.message_types_by_name['FileEvent'] = _FILEEVENT
DESCRIPTOR.message_types_by_name['Process'] = _PROCESS
DESCRIPTOR.message_types_by_name['KernelFunctionCallEvent'] = _KERNELFUNCTIONCALLEVENT
DESCRIPTOR.message_types_by_name['NetworkEvent'] = _NETWORKEVENT
DESCRIPTOR.message_types_by_name['PerformanceEventValue'] = _PERFORMANCEEVENTVALUE
DESCRIPTOR.message_types_by_name['PerformanceEvent'] = _PERFORMANCEEVENT
DESCRIPTOR.enum_types_by_name['ContainerEventType'] = _CONTAINEREVENTTYPE
DESCRIPTOR.enum_types_by_name['ProcessEventType'] = _PROCESSEVENTTYPE
DESCRIPTOR.enum_types_by_name['SyscallEventType'] = _SYSCALLEVENTTYPE
DESCRIPTOR.enum_types_by_name['FileEventType'] = _FILEEVENTTYPE
DESCRIPTOR.enum_types_by_name['KernelFunctionCallEventType'] = _KERNELFUNCTIONCALLEVENTTYPE
DESCRIPTOR.enum_types_by_name['NetworkEventType'] = _NETWORKEVENTTYPE
DESCRIPTOR.enum_types_by_name['PerformanceEventType'] = _PERFORMANCEEVENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TelemetryEvent = _reflection.GeneratedProtocolMessageType('TelemetryEvent', (_message.Message,), dict(
  DESCRIPTOR = _TELEMETRYEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.TelemetryEvent)
  ))
_sym_db.RegisterMessage(TelemetryEvent)

ChargenEvent = _reflection.GeneratedProtocolMessageType('ChargenEvent', (_message.Message,), dict(
  DESCRIPTOR = _CHARGENEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ChargenEvent)
  ))
_sym_db.RegisterMessage(ChargenEvent)

TickerEvent = _reflection.GeneratedProtocolMessageType('TickerEvent', (_message.Message,), dict(
  DESCRIPTOR = _TICKEREVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.TickerEvent)
  ))
_sym_db.RegisterMessage(TickerEvent)

ContainerEvent = _reflection.GeneratedProtocolMessageType('ContainerEvent', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINEREVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ContainerEvent)
  ))
_sym_db.RegisterMessage(ContainerEvent)

ProcessEvent = _reflection.GeneratedProtocolMessageType('ProcessEvent', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ProcessEvent)
  ))
_sym_db.RegisterMessage(ProcessEvent)

SyscallEvent = _reflection.GeneratedProtocolMessageType('SyscallEvent', (_message.Message,), dict(
  DESCRIPTOR = _SYSCALLEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.SyscallEvent)
  ))
_sym_db.RegisterMessage(SyscallEvent)

FileEvent = _reflection.GeneratedProtocolMessageType('FileEvent', (_message.Message,), dict(
  DESCRIPTOR = _FILEEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.FileEvent)
  ))
_sym_db.RegisterMessage(FileEvent)

Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), dict(
  DESCRIPTOR = _PROCESS,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.Process)
  ))
_sym_db.RegisterMessage(Process)

KernelFunctionCallEvent = _reflection.GeneratedProtocolMessageType('KernelFunctionCallEvent', (_message.Message,), dict(

  FieldValue = _reflection.GeneratedProtocolMessageType('FieldValue', (_message.Message,), dict(
    DESCRIPTOR = _KERNELFUNCTIONCALLEVENT_FIELDVALUE,
    __module__ = 'capsule8.api.v0.telemetry_event_pb2'
    # @@protoc_insertion_point(class_scope:capsule8.api.v0.KernelFunctionCallEvent.FieldValue)
    ))
  ,

  ArgumentsEntry = _reflection.GeneratedProtocolMessageType('ArgumentsEntry', (_message.Message,), dict(
    DESCRIPTOR = _KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY,
    __module__ = 'capsule8.api.v0.telemetry_event_pb2'
    # @@protoc_insertion_point(class_scope:capsule8.api.v0.KernelFunctionCallEvent.ArgumentsEntry)
    ))
  ,
  DESCRIPTOR = _KERNELFUNCTIONCALLEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.KernelFunctionCallEvent)
  ))
_sym_db.RegisterMessage(KernelFunctionCallEvent)
_sym_db.RegisterMessage(KernelFunctionCallEvent.FieldValue)
_sym_db.RegisterMessage(KernelFunctionCallEvent.ArgumentsEntry)

NetworkEvent = _reflection.GeneratedProtocolMessageType('NetworkEvent', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.NetworkEvent)
  ))
_sym_db.RegisterMessage(NetworkEvent)

PerformanceEventValue = _reflection.GeneratedProtocolMessageType('PerformanceEventValue', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMANCEEVENTVALUE,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.PerformanceEventValue)
  ))
_sym_db.RegisterMessage(PerformanceEventValue)

PerformanceEvent = _reflection.GeneratedProtocolMessageType('PerformanceEvent', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMANCEEVENT,
  __module__ = 'capsule8.api.v0.telemetry_event_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.PerformanceEvent)
  ))
_sym_db.RegisterMessage(PerformanceEvent)


_KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY.has_options = True
_KERNELFUNCTIONCALLEVENT_ARGUMENTSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
